==> kubernetes-model-1.0.0-sources.jar: io/fabric8/kubernetes/api/model/EnvVarBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class EnvVarBuilder extends EnvVarFluent<EnvVarBuilder> implements VisitableBuilder<EnvVar,EnvVarBuilder>{

     EnvVarFluent<?> fluent;
public EnvVarBuilder(){
    this(new EnvVar());
}
public EnvVarBuilder( EnvVarFluent<?> fluent ){
    this(fluent, new EnvVar());
}
public EnvVarBuilder( EnvVarFluent<?> fluent , EnvVar instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withValue(instance.getValue()); fluent.withValueFrom(instance.getValueFrom()); 
}
public EnvVarBuilder( EnvVar instance ){
    this.fluent = this; this.withName(instance.getName()); this.withValue(instance.getValue()); this.withValueFrom(instance.getValueFrom()); 
}

public EditableEnvVar build(){
    EditableEnvVar buildable = new EditableEnvVar(fluent.getName(),fluent.getValue(),fluent.getValueFrom());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.7-sources.jar: io/fabric8/kubernetes/api/model/EnvVarBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class EnvVarBuilder extends EnvVarFluent<EnvVarBuilder> implements VisitableBuilder<EnvVar,EnvVarBuilder>{

     EnvVarFluent<?> fluent;
public EnvVarBuilder(){
    this(new EnvVar());
}
public EnvVarBuilder( EnvVarFluent<?> fluent ){
    this(fluent, new EnvVar());
}
public EnvVarBuilder( EnvVarFluent<?> fluent , EnvVar instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withValue(instance.getValue()); fluent.withValueFrom(instance.getValueFrom()); 
}
public EnvVarBuilder( EnvVar instance ){
    this.fluent = this; this.withName(instance.getName()); this.withValue(instance.getValue()); this.withValueFrom(instance.getValueFrom()); 
}

public EditableEnvVar build(){
    EditableEnvVar buildable = new EditableEnvVar(fluent.getName(),fluent.getValue(),fluent.getValueFrom());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
EnvVarBuilder that = (EnvVarBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
